;; Generated package description from po-mode.el  -*- no-byte-compile: t -*-
(define-package "po-mode" "2.32.0.20260127.50952" "major mode for GNU gettext PO files" '((emacs "23")) :commit "24d793df3cffd2fa7636be6f00c2f283577655d4" :url "https://elpa.gnu.org/packages/po-mode.html" :keywords '("i18n" "gettext"))
